@@ -153,6 +153,8 @@ types: list[str] = [
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
     "AWS::Bedrock::ApplicationInferenceProfile",
+    "AWS::Bedrock::AutomatedReasoningPolicy",
+    "AWS::Bedrock::AutomatedReasoningPolicyVersion",
     "AWS::Bedrock::Blueprint",
     "AWS::Bedrock::DataAutomationProject",
     "AWS::Bedrock::DataSource",
@@ -165,6 +167,10 @@ types: list[str] = [
     "AWS::Bedrock::KnowledgeBase",
     "AWS::Bedrock::Prompt",
     "AWS::Bedrock::PromptVersion",
+    "AWS::BedrockAgentCore::BrowserCustom",
+    "AWS::BedrockAgentCore::CodeInterpreterCustom",
+    "AWS::BedrockAgentCore::Runtime",
+    "AWS::BedrockAgentCore::RuntimeEndpoint",
     "AWS::Billing::BillingView",
     "AWS::BillingConductor::BillingGroup",
     "AWS::BillingConductor::CustomLineItem",
@@ -374,6 +380,7 @@ types: list[str] = [
     "AWS::DataZone::EnvironmentActions",
     "AWS::DataZone::EnvironmentBlueprintConfiguration",
     "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
     "AWS::DataZone::GroupProfile",
     "AWS::DataZone::Owner",
     "AWS::DataZone::PolicyGrant",
@@ -443,6 +450,8 @@ types: list[str] = [
     "AWS::EC2::LocalGatewayRouteTable",
     "AWS::EC2::LocalGatewayRouteTableVPCAssociation",
     "AWS::EC2::LocalGatewayRouteTableVirtualInterfaceGroupAssociation",
+    "AWS::EC2::LocalGatewayVirtualInterface",
+    "AWS::EC2::LocalGatewayVirtualInterfaceGroup",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
@@ -991,11 +1000,13 @@ types: list[str] = [
     "AWS::Notifications::ManagedNotificationAdditionalChannelAssociation",
     "AWS::Notifications::NotificationConfiguration",
     "AWS::Notifications::NotificationHub",
+    "AWS::Notifications::OrganizationalUnitAssociation",
     "AWS::NotificationsContacts::EmailContact",
     "AWS::ODB::CloudAutonomousVmCluster",
     "AWS::ODB::CloudExadataInfrastructure",
     "AWS::ODB::CloudVmCluster",
     "AWS::ODB::OdbNetwork",
+    "AWS::ODB::OdbPeeringConnection",
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
@@ -1224,6 +1235,13 @@ types: list[str] = [
     "AWS::SES::ReceiptRuleSet",
     "AWS::SES::Template",
     "AWS::SES::VdmAttributes",
+    "AWS::SMSVOICE::ConfigurationSet",
+    "AWS::SMSVOICE::OptOutList",
+    "AWS::SMSVOICE::PhoneNumber",
+    "AWS::SMSVOICE::Pool",
+    "AWS::SMSVOICE::ProtectConfiguration",
+    "AWS::SMSVOICE::ResourcePolicy",
+    "AWS::SMSVOICE::SenderId",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicInlinePolicy",
